Class: Array
Instance Method Summary collapse
-
#excluding(*keys) ⇒ Object
Return a new Array, excluding the specified list of values.
Instance Method Details
#excluding(*keys) ⇒ Object
Return a new Array, excluding the specified list of values.
71 72 73 74 |
# File 'lib/cloudkit.rb', line 71 def excluding(*keys) trimmed = self.dup trimmed.reject{|v| keys.include?(v)} end |